@@ -10,6 +10,8 @@
 #include <transportbase.h>
 #include <transporttype.h>
 
+#include <memory>
+
 class TransportPrivate;
 namespace QKeychain
 {
@@ -119,7 +121,7 @@ protected:
       Creates a Transport object. Should only be used by TransportManager.
       @param cfgGroup The KConfig group to read its data from.
     */
-    Transport(const QString &cfgGroup);
+    explicit Transport(const QString &cfgGroup);
 
     void usrRead() override;
     bool usrSave() override;
@@ -142,7 +144,9 @@ private Q_SLOTS:
 private:
     void readTransportPasswordFinished(QKeychain::Job *baseJob);
     void loadPassword();
-    TransportPrivate *const d;
+
+private:
+    std::unique_ptr<TransportPrivate> const d;
 };
 } // namespace MailTransport
 
